# -*- coding: utf-8 -*-
from django.utils.translation import ugettext_lazy as _


import django_tables2 as tables


from . import models


class MailboxTable(tables.Table):
    class Meta:
        model = models.Mailbox
        attrs = {"class": "paleblue"}

# FIXEM: translation in inline templates are ignored
_('self')

class OutboxCsvTable(tables.Table):
    official_sender = tables.Column(accessor='sender.get_full_name',
            verbose_name=_('official_sender_header'))
    recipients = tables.Column(accessor='recipients',
            verbose_name=_('recipients_header'), orderable=False)
    real_sender = tables.TemplateColumn(
            '{% load i18n %}{% if record.real_sender %}{{ record.real_sender }}{% else %}{% trans "self" %}{% endif %}',
            verbose_name=_('real_sender_header'))
    filetype = tables.Column(accessor='filetype',
            verbose_name=_('type_header'))
    filenames = tables.Column(accessor='filenames',
            verbose_name=_('filename_header'), orderable=False)
    date = tables.Column(accessor='date',
            verbose_name=_('date_header'))


    class Meta:
        model = models.Mailbox
        fields = ('official_sender',)
        sequence = ('recipients', 'official_sender', 'real_sender', 'filetype', 'filenames', '...')
        attrs = {"class": "paleblue mailbox-table"}
        empty_text = _('No message')

class OutboxTable(tables.Table):
    official_sender = tables.Column(accessor='sender.get_full_name',
            order_by=('document__sender__last_name',
                'document__sender__first_name',
                'document__sender__username'),
            verbose_name=_('official_sender_header'))
    recipients = tables.Column(accessor='recipients',
            verbose_name=_('recipients_header'), orderable=False)
    real_sender = tables.TemplateColumn(
            '{% load i18n %}{% if record.real_sender %}{{ record.real_sender }}{% else %}{% trans "self" %}{% endif %}',
            order_by=('document__real_sender',),
            verbose_name=_('real_sender_header'))
    filetype = tables.Column(accessor='filetype',
            verbose_name=_('type_header'))
    filenames = tables.Column(accessor='filenames',
            verbose_name=_('filename_header'), orderable=False)
    date = tables.TemplateColumn('{% load humantime %}{{ record.date|humantime }}',
            verbose_name=_('date_header'))
    delete = tables.TemplateColumn(template_name='docbow/outbox_delete_column.html',
            orderable=False,
            verbose_name=' ')


    class Meta:
        model = models.Mailbox
        fields = ('official_sender',)
        sequence = ('recipients', 'official_sender', 'real_sender', 'filetype', 'filenames', '...')
        attrs = {"class": "paleblue mailbox-table refresh", "id": "outbox-table"}
        empty_text = _('No message')


class InboxCsvTable(tables.Table):
    filetype = tables.Column(
            accessor='filetype',
            verbose_name=_('type_header'))
    filenames = tables.Column(
            accessor='filenames', verbose_name=_('filename_header'),
            orderable=False)
    sender = tables.Column(
            accessor='sender', verbose_name=_('sender_header'))
    date = tables.Column(
            accessor='date', verbose_name=_('date_header'))


    class Meta:
        model = models.Mailbox
        attrs = {"class": "paleblue mailbox-table"}
        empty_text = _('No message')


class InboxTable(tables.Table):
    filetype = tables.Column(
            accessor='filetype',
            verbose_name=_('type_header'))
    filenames = tables.Column(
            accessor='filenames', verbose_name=_('filename_header'),
            orderable=False)
    sender = tables.Column(
            accessor='sender', verbose_name=_('sender_header'))
    #date = tables.Column(
    #        accessor='date', verbose_name=_('date_header'))
    date = tables.TemplateColumn('{% load humantime %}{{ record.date|humantime }}',
            verbose_name=_('date_header'))
    delete = tables.TemplateColumn(template_name='docbow/inbox_delete_column.html',
            orderable=False, verbose_name=' ')


    class Meta:
        model = models.Mailbox
        fields = ('filetype',)
        attrs = {"class": "paleblue mailbox-table refresh", "id": "outbox-table"}
        empty_text = _('No message')
