"""
This file demonstrates writing tests using the unittest module. These will pass
when you run "manage.py test".

Replace this with more appropriate tests for your application.
"""

import tempfile

from django.test import TestCase
from django.test.utils import override_settings
from django.core import management
from django.contrib.auth.models import User

from docbow_project.pfwb.models import TabellioDocType
from docbow_project.docbow.models import FileType, MailingList, Document

EXPEDITION_EMAIL = 'expedition@example.com'
RECIPIENT_EMAIL = 'recipient@example.com'
RECIPIENT_LIST_EMAIL = 'liste-ma-liste@example.com'

@override_settings(DOCBOW_PFWB_SENDMAIL_DEFAULT_TYPE_ID=1)
@override_settings(DOCBOW_PFWB_SENDMAIL_DEFAULT_TYPE_NAME='Default')
@override_settings(DOCBOW_PFWB_SENDMAIL_TABELLIO_EXPEDITION_EMAIL=EXPEDITION_EMAIL)
@override_settings(DOCBOW_PFWB_SENDMAIL_TABELLIO_EXPEDITION_USER_ID=1)
class SendMailTestCase(TestCase):
    def setUp(self):
        import app_settings
        reload(app_settings)

        self.filetype = FileType.objects.create(name='Default', id=1)
        self.pjd_filetype = FileType.objects.create(name='PJD', id=2)
        self.tabellio_doc_type = TabellioDocType.objects.create(filetype=self.pjd_filetype,
                tabellio_doc_type='PJD')
        self.expedition_user = User.objects.create(username='expedition', id=1)
        self.to_user = User.objects.create(username='recipient', email=RECIPIENT_EMAIL)
        self.to_list = MailingList.objects.create(name='ma liste')
        self.to_list.members.add(self.to_user)


    def test_expedition_mode(self):
        """
        Test sendmail management command when using the expedition mode
        """
        with tempfile.NamedTemporaryFile() as f:
            content = '''\
Message-ID: <232323232@example.com>
From: %(expedition_email)s
To: %(recipient_email)s
Subject: Mouais: monfichier.pdf
MIME-Version: 1.0
Content-Type: text/plain; charset=us-ascii
Content-Disposition: inline
User-Agent: Mutt/1.5.20 (2009-06-14)
X-Tabellio-Doc-Type: PJD
X-Tabellio-Doc-URL: https://ramcloud.stanford.edu/wiki/download/attachments/11370504/raft.pdf
Status: RO

Coucou
'''
            f.write(content)
            f.flush()
            management.call_command('sendmail', RECIPIENT_EMAIL, file=f.name,
                    sender=EXPEDITION_EMAIL)
            self.assertEqual(Document.objects.count(), 1)
            self.assertEquals(Document.objects.get().to_user.count(), 1)
            self.assertEquals(Document.objects.get().to_list.count(), 0)

    def test_expedition_mode_to_list(self):
        """
        Test sendmail management command when using the expedition mode
        """
        with tempfile.NamedTemporaryFile() as f:
            content = '''\
Message-ID: <232323232@example.com>
From: %(expedition_email)s
To: %(recipient_email)s
Subject: Mouais: monfichier.pdf
MIME-Version: 1.0
Content-Type: text/plain; charset=us-ascii
Content-Disposition: inline
User-Agent: Mutt/1.5.20 (2009-06-14)
X-Tabellio-Doc-Type: PJD
X-Tabellio-Doc-URL: https://ramcloud.stanford.edu/wiki/download/attachments/11370504/raft.pdf
Status: RO

Coucou
'''
            f.write(content)
            f.flush()
            management.call_command('sendmail', RECIPIENT_LIST_EMAIL, file=f.name,
                    sender=EXPEDITION_EMAIL)
            self.assertEqual(Document.objects.count(), 1)
            self.assertEquals(Document.objects.get().to_user.count(), 0)
            self.assertEquals(Document.objects.get().to_list.count(), 1)
            self.assertEquals(Document.objects.get().to_list.all()[0], self.to_list)
